import React, { useState, useEffect } from 'react'
import { withClient, Client } from 'cozy-client'
import StyledChallengeSpinner from 'components/CommonKit/Spinner/StyledChallengeSpinner'
import EcogestureCard from '../EcogestureCard/EcogestureCard'
import EcogestureModal from '../EcogestureModal/EcogestureModal'
import NegaWattModal from '../NegaWattModal/NegaWattModal'
import { EcogestureType } from 'services/dataChallengeContracts'
import ChallengeManager from 'services/challengeDataManagerService'
import StyledClearGreyButton from 'components/CommonKit/Button/StyledClearGreyButton'
import { translate } from 'cozy-ui/react/I18n'

interface EcogesturesListProps {
  t: Function
  client: Client
}

const EcogesturesList: React.FC<EcogesturesListProps> = ({
  t,
  client,
}: EcogesturesListProps) => {
  const [
    selectedEcogesture,
    setSelectedEcogesture,
  ] = useState<EcogestureType | null>(null)

  const [ecogestures, setEcogestures] = useState<EcogestureType[] | null>(null)
  const [openEcogestureModal, setOpenEcogestureModal] = useState(false)
  const [openNegaWattModal, setOpenNegaWattModal] = useState(false)
  const _challengeManager = new ChallengeManager(client)

  const handleClick = (ecogesture: EcogestureType) => {
    setSelectedEcogesture(ecogesture)
    setOpenEcogestureModal(true)
  }

  const handleCloseClick = () => {
    setOpenEcogestureModal(false)
  }

  const handleNegaWattClick = () => {
    setOpenNegaWattModal(true)
  }

  const handleNegaWattCloseClick = () => {
    setOpenNegaWattModal(false)
  }

  useEffect(() => {
    let subscribed = true
    async function loadEcogestures() {
      const dataAll = await _challengeManager.getAllEcogestures()
      const dataUnlocked = await _challengeManager.getUnlockedEcogestures()
      if (subscribed && dataAll) {
        if (dataUnlocked) {
          dataAll.forEach(element => {
            dataUnlocked.forEach(el => {
              if (el === element.id) {
                element.unlocked = true
              }
            })
          })
        }
        setEcogestures(dataAll)
      }
    }
    loadEcogestures()
    return () => {
      subscribed = false
    }
  }, [])

  return (
    <div className="ecogesture-root">
      {!ecogestures ? (
        <div className="content-view-loading">
          <StyledChallengeSpinner size="5em" />
        </div>
      ) : (
        <>
          <div className="negawatt-button-content">
            <StyledClearGreyButton
              color="secondary"
              onClick={handleNegaWattClick}
              fullWidth={true}
            >
              {t('NEGAWATT.QUESTION')}
            </StyledClearGreyButton>
            <NegaWattModal
              opened={openNegaWattModal}
              handleCloseClick={handleNegaWattCloseClick}
            />
          </div>
          <div className="ecogesture-content">
            {ecogestures.map((ecogesture, index) => (
              <div key={index} className="ecogesture-list-item">
                <EcogestureCard
                  ecogesture={ecogesture}
                  handleClick={handleClick}
                />
              </div>
            ))}
          </div>
        </>
      )}
      <EcogestureModal
        opened={openEcogestureModal}
        ecogesture={selectedEcogesture}
        handleCloseClick={handleCloseClick}
        border={
          selectedEcogesture
            ? selectedEcogesture.unlocked
              ? selectedEcogesture.unlocked
              : false
            : false
        }
      />
    </div>
  )
}

export default translate()(withClient(EcogesturesList))
